@@ -43,7 +43,8 @@ def init():
 
     if 'LANG' not in os.environ:
         if os.name == 'nt':
-            lang, enc = locale.getdefaultlocale()
+            lang_tuple = locale.getlocale()
+            lang = lang_tuple[0] if lang_tuple and lang_tuple[0] else 'en_US'
             os.environ['LANG'] = lang
         elif jnius:  # android
             Locale = jnius.autoclass('java.util.Locale')
@@ -102,7 +103,7 @@ def init():
         sys.argv.remove('--kivy')
 
     if pysollib.settings.TOOLKIT == 'tk':
-        from six.moves import tkinter
+        import tkinter
         root = tkinter.Tk(className=pysollib.settings.TITLE)
         root.withdraw()
         if tkinter.TkVersion < 8.4:
